@@ -8,7 +8,7 @@ from pythautomata.tests.test_moore_machines_last_symbol_queries import TestMoore
 from pythautomata.tests.test_pdfa_generator import TestPDFAGenerator
 from pythautomata.tests.test_pdfa_serialization import TestPDFASerialization
 from pythautomata.tests.test_dfa_serialization import TestDFASerialization
-from pythautomata.tests.test_DFA_generators import TestDFAGenerators
+from pythautomata.tests.test_dfa_generators import TestDFAGenerators
 from pythautomata.tests.test_automata_comparison import TestAutomataComparison
 from pythautomata.tests.test_sequence import TestSequence
 from pythautomata.tests.test_dfa_operations import TestDFAOperations
@@ -28,14 +28,13 @@ from pythautomata.tests.test_mm_loading import TestMMLoading
 
 def get_all_tests():
     return [TestDFALoading, TestDFAExporting, TestSimpleDFAGenerator, TestMinimizer,
-            TestAutomataConvertor, TestDFAGenerators, TestAutomataComparison, TestSequence, 
-            TestDFAOperations, TestAutomataDefinitions, TestPDFAGenerator, TestRegexGenerator, 
-            TestPDFASerialization,TestDFASerialization, TestPDFAMetrics, TestPDFAOperations, 
-            TestPDFALastTokenQueries, TestMooreMachinesLastSymbolQueries, 
+            TestAutomataConvertor, TestDFAGenerators, TestAutomataComparison, TestSequence,
+            TestDFAOperations, TestAutomataDefinitions, TestPDFAGenerator, TestRegexGenerator,
+            TestPDFASerialization, TestDFASerialization, TestPDFAMetrics, TestPDFAOperations,
+            TestPDFALastTokenQueries, TestMooreMachinesLastSymbolQueries,
             TestDFAToMooreMachine, TestMMLoading, TestMMExporting, TestProbabilisticFilterModel]
 
 
-
 def run():
     test_classes_to_run = get_all_tests()
     loader = TestLoader()
